==> uhub-0.1.2-2020-src.tar.gz: uhub-0.1.2-2020/src/auth.h <==
/*
 * uhub - A tiny ADC p2p connection hub
 * Copyright (C) 2007, Jan Vidar Krey
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 *
 */

#ifndef HAVE_uhub_ACL_H
#define HAVE_uhub_ACL_H

#include "uhub.h"

struct uhub_config;
struct user;
struct ip_addr_encap;

enum user_status
{
	user_banned         = -2, /* User is banned */
	user_not_allowed    = -1, /* User is not allowed to log in */
	user_not_found      =  0, /* User is not registered */
	user_auth_regular   =  1, /* User is registered */
	user_auth_operator  =  2, /* User is an operator */
	user_auth_admin     =  3, /* User is the server administrator */
};


struct access_info
{
	char* data1;       /* name of user, cid or IP range */
	char* data2;       /* password */
	int status;        /* See enum user_status (0 >= user is good). */
};


struct ip_ban_record
{
	struct ip_addr_encap lo;
	struct ip_addr_encap hi;
};

struct acl_handle
{
	struct linked_list* nicks;    /* Known nick names */
	struct linked_list* cids;     /* Known CIDs */
	struct linked_list* networks; /* IP ranges, used for banning */
};


extern int acl_initialize(struct uhub_config* config, struct acl_handle* handle);
extern int acl_shutdown(struct acl_handle* handle);

extern struct access_info* acl_get_access_info_by_name(struct acl_handle* handle, const char* name);
extern struct access_info* acl_get_access_info_by_cid(struct acl_handle* handle, const char* cid);
extern int acl_is_ip_banned(struct acl_handle* handle, const char* ip_address);

extern const char* password_generate_challenge(struct user* user);
extern int password_verify(struct user* user, const char* password);

#endif /* HAVE_uhub_ACL_H */

==> uhub-0.1.3-2147-src.tar.gz: uhub-0.1.3-2147/src/auth.h <==
/*
 * uhub - A tiny ADC p2p connection hub
 * Copyright (C) 2007, Jan Vidar Krey
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 *
 */

#ifndef HAVE_UHUB_ACL_H
#define HAVE_UHUB_ACL_H

struct hub_config;
struct user;
struct ip_addr_encap;

enum user_status
{
	user_banned         = -2, /* User is banned */
	user_not_allowed    = -1, /* User is not allowed to log in */
	user_not_found      =  0, /* User is not registered */
	user_auth_regular   =  1, /* User is registered */
	user_auth_operator  =  2, /* User is an operator */
	user_auth_admin     =  3, /* User is the server administrator */
};


struct access_info
{
	char* data1;       /* name of user, cid or IP range */
	char* data2;       /* password */
	int status;        /* See enum user_status (0 >= user is good). */
};


struct ip_ban_record
{
	struct ip_addr_encap lo;
	struct ip_addr_encap hi;
};

struct acl_handle
{
	struct linked_list* nicks;    /* Known nick names */
	struct linked_list* cids;     /* Known CIDs */
	struct linked_list* networks; /* IP ranges, used for banning */
};


extern int acl_initialize(struct hub_config* config, struct acl_handle* handle);
extern int acl_shutdown(struct acl_handle* handle);

extern struct access_info* acl_get_access_info_by_name(struct acl_handle* handle, const char* name);
extern struct access_info* acl_get_access_info_by_cid(struct acl_handle* handle, const char* cid);
extern int acl_is_ip_banned(struct acl_handle* handle, const char* ip_address);

extern const char* password_generate_challenge(struct user* user);
extern int password_verify(struct user* user, const char* password);

#endif /* HAVE_UHUB_ACL_H */
